test Package
============

:mod:`test` Package
-------------------

.. automodule:: stoqlib.gui.test
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`uitestutils` Module
-------------------------

.. automodule:: stoqlib.gui.test.uitestutils
    :members:
    :undoc-members:
    :show-inheritance:

